===
API
===

.. module:: aiapi

The library provides classes which are usable by third party tools.

.. note::

    This project is still in *beta* stage, so the API is not finalized yet.

Modules:

.. toctree::
   :maxdepth: 2

   aiapi.TODO_MODULE_NAME <api_TODO_MODULE_NAME>

